@@ -15,8 +15,9 @@ import datetime
 import uuid
 
 from django.utils import datetime_safe
-from keystoneclient import access
-from keystoneclient import service_catalog
+from keystoneauth1.access import access
+from keystoneauth1.access import service_catalog
+from keystoneclient.common import cms
 from keystoneclient.v3 import domains
 from keystoneclient.v3 import projects
 from keystoneclient.v3 import roles
@@ -37,7 +38,7 @@ class TestResponse(requests.Response):
 
     def __init__(self, data):
         self._text = None
-        super(TestResponse, self)
+        super(TestResponse, self).__init__()
         if isinstance(data, dict):
             self.status_code = data.get('status_code', 200)
             self.headers = data.get('headers', None)
@@ -54,7 +55,7 @@ class TestResponse(requests.Response):
         return self._text
 
 
-def generate_test_data():
+def generate_test_data(pki=False):
     '''Builds a set of test_data data as returned by Keystone V2.'''
     test_data = TestDataContainer()
 
@@ -177,7 +178,13 @@ def generate_test_data():
     # Tokens
     tomorrow = datetime_safe.datetime.now() + datetime.timedelta(days=1)
     expiration = datetime_safe.datetime.isoformat(tomorrow)
-    auth_token = uuid.uuid4().hex
+    if pki:
+        # We don't need a real PKI token, but just the prefix to make the
+        # keystone client treat it as a PKI token
+        auth_token = cms.PKI_ASN1_PREFIX + uuid.uuid4().hex
+    else:
+        auth_token = uuid.uuid4().hex
+
     auth_response_headers = {
         'X-Subject-Token': auth_token
     }
@@ -211,11 +218,36 @@ def generate_test_data():
         }
     }
 
-    test_data.scoped_access_info = access.AccessInfo.factory(
+    test_data.scoped_access_info = access.create(
         resp=auth_response,
         body=scoped_token_dict
     )
 
+    domain_token_dict = {
+        'token': {
+            'methods': ['password'],
+            'expires_at': expiration,
+            'domain': {
+                'id': domain_dict['id'],
+                'name': domain_dict['name'],
+            },
+            'user': {
+                'id': user_dict['id'],
+                'name': user_dict['name'],
+                'domain': {
+                    'id': domain_dict['id'],
+                    'name': domain_dict['name']
+                }
+            },
+            'roles': [role_dict],
+            'catalog': [keystone_service, nova_service]
+        }
+    }
+    test_data.domain_scoped_access_info = access.create(
+        resp=auth_response,
+        body=domain_token_dict
+    )
+
     unscoped_token_dict = {
         'token': {
             'methods': ['password'],
@@ -232,16 +264,81 @@ def generate_test_data():
         }
     }
 
-    test_data.unscoped_access_info = access.AccessInfo.factory(
+    test_data.unscoped_access_info = access.create(
         resp=auth_response,
         body=unscoped_token_dict
     )
 
     # Service Catalog
-    test_data.service_catalog = service_catalog.ServiceCatalog.factory({
-        'methods': ['password'],
-        'user': {},
-        'catalog': [keystone_service, nova_service],
-    }, token=auth_token)
+    test_data.service_catalog = service_catalog.ServiceCatalogV3(
+        [keystone_service, nova_service])
+
+    # federated user
+    federated_scoped_token_dict = {
+        'token': {
+            'methods': ['password'],
+            'expires_at': expiration,
+            'project': {
+                'id': project_dict_1['id'],
+                'name': project_dict_1['name'],
+                'domain': {
+                    'id': domain_dict['id'],
+                    'name': domain_dict['name']
+                }
+            },
+            'user': {
+                'id': user_dict['id'],
+                'name': user_dict['name'],
+                'domain': {
+                    'id': domain_dict['id'],
+                    'name': domain_dict['name']
+                },
+                'OS-FEDERATION': {
+                    'identity_provider': 'ACME',
+                    'protocol': 'OIDC',
+                    'groups': [
+                        {'id': uuid.uuid4().hex},
+                        {'id': uuid.uuid4().hex}
+                    ]
+                }
+            },
+            'roles': [role_dict],
+            'catalog': [keystone_service, nova_service]
+        }
+    }
+
+    test_data.federated_scoped_access_info = access.create(
+        resp=auth_response,
+        body=federated_scoped_token_dict
+    )
+
+    federated_unscoped_token_dict = {
+        'token': {
+            'methods': ['password'],
+            'expires_at': expiration,
+            'user': {
+                'id': user_dict['id'],
+                'name': user_dict['name'],
+                'domain': {
+                    'id': domain_dict['id'],
+                    'name': domain_dict['name']
+                },
+                'OS-FEDERATION': {
+                    'identity_provider': 'ACME',
+                    'protocol': 'OIDC',
+                    'groups': [
+                        {'id': uuid.uuid4().hex},
+                        {'id': uuid.uuid4().hex}
+                    ]
+                }
+            },
+            'catalog': [keystone_service]
+        }
+    }
+
+    test_data.federated_unscoped_access_info = access.create(
+        resp=auth_response,
+        body=federated_unscoped_token_dict
+    )
 
     return test_data
